@@ -4,7 +4,9 @@ from .base import *
 from .logic import *
 from .simulation import *
 from .storage import *
+from .schematic import *
 
 import py4hw.gui
 import py4hw.debug
-import py4hw.schematic
+
+from nbwavedrom import draw as draw_waveform
\ No newline at end of file
