@@ -203,7 +203,7 @@ class Wire:
     # this is the list of prepared wires, 
     prepared = []
     
-    def __init__(self, parent, name : str, width: int ):
+    def __init__(self, parent, name : str, width: int = 1 ):
         self.parent = parent
         self.name = name
         self.width = width
@@ -211,6 +211,9 @@ class Wire:
         self.sinks = []
         self.source = None
         
+    def getFullPath(self)->str:
+        return self.parent.getFullPath() + '[{}]'.format(self.name)
+    
     def getWidth(self) -> int:
         return self.width
     
@@ -325,6 +328,9 @@ class InPort:
 
         if (parent.isPrimitive()):
             wire.addSink(self)
+            
+    def getFullPath(self):
+        return self.parent.getFullPath() + '[{}]'.format(self.name)
     
 class OutPort:
     """
@@ -358,6 +364,9 @@ class OutPort:
         if (parent.isPrimitive()):
             wire.setSource(self)
 
+    def getFullPath(self):
+        return self.parent.getFullPath() + '[{}]'.format(self.name)
+
 class InterfaceSource:
     def __init__(self, name:str, ports):
         self.name = name
@@ -392,6 +401,8 @@ class HWSystem(Logic):
 
         if (self.simulator == None):
             self.simulator = Simulator(self)
+        else: 
+            self.simulator.topologicalSort() # Updates existing simulator
             
         return self.simulator
         
