@@ -67,8 +67,6 @@ class Or(Logic):
                 idx = idx + 1
 
 
-
-
 class And(Logic):
     """
     Binary And
@@ -103,7 +101,6 @@ class And(Logic):
                 idx = idx + 1
 
 
-
 class Nand(Logic):
     """
     Binary Nand
@@ -121,8 +118,6 @@ class Nand(Logic):
         Not(self, "Not", self.mid, r)
 
 
-
-
 class Not(Logic):
     def __init__(self, parent, name: str, a: Wire, r: Wire):
         super().__init__(parent, name)
@@ -136,8 +131,6 @@ class Not(Logic):
         return NotSymbol(self, x, y)
 
 
-
-
 class Xor(Logic):
     """
     Binary Xor
@@ -297,7 +290,7 @@ class Constant(Logic):
     A constant value
     """
 
-    def __init__(self, parent: Logic, name: str, value, r: Wire):
+    def __init__(self, parent: Logic, name: str, value: int, r: Wire):
         super().__init__(parent, name)
         self.value = value
         self.r = self.addOut("r", r)
@@ -306,6 +299,22 @@ class Constant(Logic):
         self.r.put(self.value)
         #print(self.name, '=', self.value)
 
+class Sequence(Logic):
+    """
+    A sequence of value
+    """
+
+    def __init__(self, parent: Logic, name: str, values: list(), r: Wire):
+        super().__init__(parent, name)
+        self.r = self.addOut("r", r)
+
+        self.values = values
+        self.n = len(values)
+        self.i = 0
+        
+    def clock(self):
+        self.r.prepare(self.values[self.i])
+        self.i = ( self.i +1 ) % self.n
 
 class SignExtend(Logic):
     def __init__(self, parent: Logic, name: str, a: Wire, r: Wire):
@@ -561,18 +570,57 @@ class Comparator(Logic):
 
 class Scope(Logic):
 
-    def __init__(self, parent, name: str, x: Wire):
+    def __init__(self, parent: Logic, name: str, wires):
+        """
+        Parameters
+        ----------
+        parent : Logic
+            Parent circuit.
+        name : str
+            Name of the instance.
+        wires
+            Wire or list of wire to monitor.
+
+        Returns
+        -------
+        None.
         """
 
+        super().__init__(parent, name)
+        self.wires = wires if isinstance(wires, list) else [wires]
+        for x in self.wires:
+            self.addIn(x.name, x)
+
+        # Get simulator
+        sim = parent
+        while sim.parent != None:
+            sim = sim.parent
+
+        sim.getSimulator().addListener(self)
+
+    def simulatorUpdated(self):
+        head = f"Scope [{self.name}]:"
+        print(head)
+
+        for x in self.wires:
+            print(f"{x.name}={x.get()}")
+
+        print("-" * len(head))
+
+
+class Waveform(Logic):
+
+    def __init__(self, parent: Logic, name: str, wires):
+        """
 
         Parameters
         ----------
-        parent : TYPE
-            Parent cell.
+        parent : Logic
+              Parent circuit.
         name : str
             Name of the instance.
-        x : Wire
-            Wire to monitor.
+        wires
+              Wire or list of wire to monitor.
 
         Returns
         -------
@@ -580,49 +628,53 @@ class Scope(Logic):
 
         """
         super().__init__(parent, name)
-        self.name = name
-        self.x = self.addIn("x", x)
+        self.waves = {}
+        self.prevs = {}
+        self.ck = {"name": "CK", "wave": "P"}
 
-    def propagate(self):
-        print("{}={}".format(self.name, self.x.get()))
+        self.wires = wires if isinstance(wires, list) else [wires]
+        for x in self.wires:
+            self.addIn(x.name, x)
+            self.waves[x] = {"name": x.name, "wave": "x", "data": []}
+            self.prevs[x] = None
 
+        # Get simulator
+        self.sim = parent
+        while self.sim.parent != None:
+            self.sim = self.sim.parent
 
-class Waveform(Logic):
+        self.sim.getSimulator().addListener(self)
 
-    def __init__(self, parent, name: str, x: Wire):
-      """
+    def simulatorUpdated(self):
+        for x in self.wires:
+            if self.prevs[x] == x.get():
+                self.waves[x]["wave"] += "."
+            elif x.getWidth() == 1:
+                self.waves[x]["wave"] += str(x.get())
+            else:
+                self.waves[x]["wave"] += "2"
+                self.waves[x]["data"].append(x.get())
 
-      Parameters
-      ----------
-      parent : TYPE
-          Parent cell.
-      name : str
-          Name of the instance.
-      x : Wire
-          Wire to monitor.
+            self.prevs[x] = x.get()
 
-      Returns
-      -------
-      None.
+        self.ck["wave"] += "."
 
-      """
-      super().__init__(parent, name)
-      self.name = name
-      self.x = self.addIn("x", x)
-      self.wave = {"name": name, "wave": "x", "data": []}
-      self.prev = None
+    def get_waveform(self, with_ck=True):
+        signals = list(self.waves.values())
+        for x in signals:
+            x["wave"] += "x"
 
-    def propagate(self):
-      if self.prev == self.x.get():
-        self.wave["wave"] += "."
-      elif self.x.getWidth() == 1:
-        self.wave["wave"] += str(self.x.get())
-      else:
-        self.wave["wave"] += "2"
-        self.wave["data"].append(self.x.get())
+        if with_ck:
+            ck = self.ck.copy()
+            ck["wave"] += "x"
+            signals.insert(0, ck)
 
-      self.prev = self.x.get()
+        waveform = {
+            "signal": signals,
+            "head": {
+                "text": self.name,
+                "tock": 0,
+            }
+        }
 
-    def get_wave_raw(self):
-      self.wave["wave"] += "x"
-      return self.wave
+        return waveform
