@@ -19,6 +19,9 @@ class Simulator:
         None.
 
         """
+        if sys.simulator != None:
+            return
+
         self.sys = sys;
         
         self.topologicalSort()
@@ -26,7 +29,13 @@ class Simulator:
         
         for obj in self.propagatables:
             obj.propagate();
-        
+    
+    def __new__(cls, sys:HWSystem):
+        if sys.simulator != None:
+            sys.simulator.topologicalSort() # Updates existing simulator
+            return sys.simulator
+        else:
+            return super().__new__(cls)
 
         
     def topologicalSort(self):
@@ -47,7 +56,6 @@ class Simulator:
         
         self.clockables = []
         self.propagatables = []
-        self.wave_scopes = []
        
         leaves = self.sys.allLeaves()
         
@@ -56,8 +64,6 @@ class Simulator:
                 self.clockables.append(leaf)
             if (leaf.isPropagatable()):
                 self.propagatables.append(leaf)
-            if (isinstance(leaf, Waveform)):
-                self.wave_scopes.append(leaf)
                 
         # Now sort the propagatables list
         anyChange = True 
@@ -156,20 +162,4 @@ class Simulator:
         
     def _notifyListeners(self):
         for listener in self.listeners:
-            listener.simulatorUpdated()
-    
-    def get_waveform(self, name:str = "", with_ck = True):
-      signals = [wf.get_wave_raw() for wf in self.wave_scopes]
-      if (with_ck):
-          cklen = len(signals[0]["wave"])-1
-          signals.insert(0, {"name": "CK", "wave": "P" + "."*cklen})
-
-      waveform = {
-        "signal": signals,
-        "head":{
-          "text": name,
-          "tock": 0,
-        }
-      }
-      
-      return waveform
\ No newline at end of file
+            listener.simulatorUpdated()
\ No newline at end of file
